@@ -42,9 +42,7 @@ class Precision(ClassificationMetric):
     """
 
     def __init__(self, name: str = "precision") -> None:
-        super().__init__(
-            name=name, canonical_name="precision", increasing=False
-        )
+        super().__init__(name=name, canonical_name="precision", increasing=False)
 
     def compute(
         self,
@@ -86,9 +84,7 @@ class Precision(ClassificationMetric):
         # The following accounts for the and sets the first precision value to
         # 1.0 if the first recall and precision are both zero.
         if (tp + fp)[0] == 0.0 and len(p) > 1:
-            initial_precision = tf.constant(
-                [tf.constant([1.0]), tf.zeros(len(p) - 1)], axis=0
-            )
+            initial_precision = tf.constant([tf.constant([1.0]), tf.zeros(len(p) - 1)], axis=0)
             p = p + initial_precision
 
         return p
