@@ -1,11 +1,17 @@
-import tensorflow as tf
 import numpy as np
-from tensorflow_similarity.losses import TripletLoss
-from tensorflow_similarity.losses import PNLoss
-from tensorflow_similarity.losses import SoftNearestNeighborLoss
+import tensorflow as tf
 
+from tensorflow_similarity.losses import (
+    MultiSimilarityLoss,
+    PNLoss,
+    SoftNearestNeighborLoss,
+    TripletLoss,
+)
 
 # [triplet loss]
+from tensorflow_similarity.losses.xbm_loss import XBM
+
+
 def test_triplet_loss_serialization():
     loss = TripletLoss()
     config = loss.get_config()
@@ -19,8 +25,7 @@ def triplet_hard_loss_np(labels, embedding, margin, dist_func, soft=False):
 
     num_data = embedding.shape[0]
     # Reshape labels to compute adjacency matrix.
-    labels_reshaped = np.reshape(labels.astype(np.float32),
-                                 (labels.shape[0], 1))
+    labels_reshaped = np.reshape(labels.astype(np.float32), (labels.shape[0], 1))
 
     adjacency = np.equal(labels_reshaped, labels_reshaped.T)
     pdist_matrix = dist_func(embedding)
@@ -47,8 +52,7 @@ def triplet_hard_loss_np(labels, embedding, margin, dist_func, soft=False):
         if soft:
             loss_np += np.log1p(np.exp(max_pos_distance - min_neg_distance))
         else:
-            loss_np += np.maximum(0.0,
-                                  max_pos_distance - min_neg_distance + margin)
+            loss_np += np.maximum(0.0, max_pos_distance - min_neg_distance + margin)
 
     loss_np /= num_data
     return loss_np
@@ -57,7 +61,7 @@ def triplet_hard_loss_np(labels, embedding, margin, dist_func, soft=False):
 def test_triplet_loss():
     num_inputs = 10
     # y_true: labels
-    y_true = tf.random.uniform((num_inputs, ), 0, 10, dtype=tf.int32)
+    y_true = tf.random.uniform((num_inputs,), 0, 10, dtype=tf.int32)
     # y_preds: embedding
     y_preds = tf.random.uniform((num_inputs, 20), 0, 1)
     tpl = TripletLoss()
@@ -69,11 +73,10 @@ def test_triplet_loss():
 def test_triplet_loss_easy():
     num_inputs = 10
     # y_true: labels
-    y_true = tf.random.uniform((num_inputs, ), 0, 3, dtype=tf.int32)
+    y_true = tf.random.uniform((num_inputs,), 0, 3, dtype=tf.int32)
     # y_preds: embedding
     y_preds = tf.random.uniform((num_inputs, 16), 0, 1)
-    tpl = TripletLoss(positive_mining_strategy='easy',
-                      negative_mining_strategy='easy')
+    tpl = TripletLoss(positive_mining_strategy="easy", negative_mining_strategy="easy")
     # y_true, y_preds
     loss = tpl(y_true, y_preds)
     assert loss > 0
@@ -82,11 +85,10 @@ def test_triplet_loss_easy():
 def test_triplet_loss_semi_hard():
     num_inputs = 10
     # y_true: labels
-    y_true = tf.random.uniform((num_inputs, ), 0, 3, dtype=tf.int32)
+    y_true = tf.random.uniform((num_inputs,), 0, 3, dtype=tf.int32)
     # y_preds: embedding
     y_preds = tf.random.uniform((num_inputs, 16), 0, 1)
-    tpl = TripletLoss(positive_mining_strategy='easy',
-                      negative_mining_strategy='semi-hard')
+    tpl = TripletLoss(positive_mining_strategy="easy", negative_mining_strategy="semi-hard")
     # y_true, y_preds
     loss = tpl(y_true, y_preds)
     assert loss
@@ -95,11 +97,10 @@ def test_triplet_loss_semi_hard():
 def test_triplet_loss_hard():
     num_inputs = 10
     # y_true: labels
-    y_true = tf.random.uniform((num_inputs, ), 0, 3, dtype=tf.int32)
+    y_true = tf.random.uniform((num_inputs,), 0, 3, dtype=tf.int32)
     # y_preds: embedding
     y_preds = tf.random.uniform((num_inputs, 16), 0, 1)
-    tpl = TripletLoss(positive_mining_strategy='hard',
-                      negative_mining_strategy='hard')
+    tpl = TripletLoss(positive_mining_strategy="hard", negative_mining_strategy="hard")
     # y_true, y_preds
     loss = tpl(y_true, y_preds)
     assert loss
@@ -118,7 +119,7 @@ def test_pn_loss_serialization():
 def test_np_loss():
     num_inputs = 10
     # y_true: labels
-    y_true = tf.random.uniform((num_inputs, ), 0, 10, dtype=tf.int32)
+    y_true = tf.random.uniform((num_inputs,), 0, 10, dtype=tf.int32)
     # y_preds: embedding
     y_preds = tf.random.uniform((num_inputs, 20), 0, 1)
     pnl = PNLoss()
@@ -137,7 +138,7 @@ def test_softnn_loss_serialization():
     assert loss.temperature == loss2.temperature
 
 
-def softnn_util(y_true, x, temperature = 1):
+def softnn_util(y_true, x, temperature=1):
     """
     A simple loop based implementation of soft
     nearest neighbor loss to test the code.
@@ -153,15 +154,15 @@ def softnn_util(y_true, x, temperature = 1):
         numerator = 0
         denominator = 0
         for j in range(batch_size):
-            if i == j: continue
+            if i == j:
+                continue
             if y_true[i] == y_true[j]:
-                numerator += np.exp(-1 * 
-                    np.sum(np.square(x[i] - x[j])) / temperature)
-            denominator += np.exp(-1 * 
-                    np.sum(np.square(x[i] - x[j])) / temperature)
-        if numerator == 0: continue
-        loss += np.log(numerator/denominator)
-    return -loss/batch_size
+                numerator += np.exp(-1 * np.sum(np.square(x[i] - x[j])) / temperature)
+            denominator += np.exp(-1 * np.sum(np.square(x[i] - x[j])) / temperature)
+        if numerator == 0:
+            continue
+        loss += np.log(numerator / denominator)
+    return -loss / batch_size
 
 
 def test_softnn_loss():
@@ -178,3 +179,63 @@ def test_softnn_loss():
     loss_check = softnn_util(y_true, x, temperature)
     loss_diff = loss.numpy() - loss_check
     assert np.abs(loss_diff) < 1e-3
+
+
+def test_xbm_loss():
+    batch_size = 6
+    embed_dim = 16
+
+    embeddings1 = tf.random.uniform(shape=[batch_size, embed_dim])
+    labels1 = tf.constant(
+        [
+            [1],
+            [1],
+            [2],
+            [2],
+            [3],
+            [3],
+        ],
+        dtype=tf.int32,
+    )
+
+    embeddings2 = tf.random.uniform(shape=[batch_size, embed_dim])
+    labels2 = tf.constant(
+        [
+            [4],
+            [4],
+            [5],
+            [5],
+            [6],
+            [6],
+        ],
+        dtype=tf.int32,
+    )
+
+    distance = "cosine"
+    loss = MultiSimilarityLoss(distance=distance)
+    loss_nowarm = XBM(loss, memory_size=12, warmup_steps=0)
+
+    # test enqueue
+    loss_nowarm(labels1, embeddings1)
+    assert loss_nowarm._y_pred_memory.numpy().shape == (batch_size, embed_dim)
+    tf.assert_equal(loss_nowarm._y_true_memory, labels1)
+
+    loss_nowarm(labels2, embeddings2)
+    assert loss_nowarm._y_pred_memory.numpy().shape == (2 * batch_size, embed_dim)
+    tf.assert_equal(loss_nowarm._y_true_memory, tf.concat([labels2, labels1], axis=0))
+
+    # test dequeue
+    loss_nowarm(labels2, embeddings2)
+    assert loss_nowarm._y_pred_memory.numpy().shape == (2 * batch_size, embed_dim)
+    tf.assert_equal(loss_nowarm._y_true_memory, tf.concat([labels2, labels2], axis=0))
+
+    # test warmup
+    loss_warm = XBM(loss, memory_size=12, warmup_steps=1)
+
+    loss_warm(labels1, embeddings1)
+    assert loss_warm._y_pred_memory.numpy().shape == (0, embed_dim)
+    tf.assert_equal(loss_warm._y_true_memory, tf.constant([[]], dtype=tf.int32))
+
+    loss_warm(labels2, embeddings2)
+    assert loss_warm._y_pred_memory.numpy().shape == (batch_size, embed_dim)
+    tf.assert_equal(loss_warm._y_true_memory, labels2)
